##  Advanced
This Advanced tab allows for Json customization of the portal settings.
**Note**
To enable this section, you may reach out to support at [SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support"). If you're an SAP customer, submit a request from the [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.
![Advanced tab in LeanIX portal configuration showing editable JSON settings.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274efa707a441014b10cc30aba3d6caa_LowRes.png)
![LeanIX Application Portal with search bar, category filters, and application cards.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274541cd7a44101491ccbeba7ad24b6e_LowRes.png)
Please note that the status for each Fact Sheet can be based on the value of the Ordering State field on the Fact Sheet. This field can be made visible by using the Self-Configuration feature and moving it from the Unused Fields section to another section, e.g. Name & Description.
Furthermore, as an Admin you can also configure the Relations which will be displayed on the details screen of a Fact Sheet.
![Application details screen showing description, status, successors, business capabilities, and tags.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio7521412cf141414f8b11cb14dda82e54_HiRes.png)
**Note**
Transient Users with SSO: A great benefit of SSO integration with your (external) Identity Provider is the ability to enable Transient user roles. This allows users within your organisation to access a lightweight version of SAP LeanIX via our self-service portals or catalogs.
You can then link these portals in your existing intranet, wiki, or any other system sitting behind your SSO. You now have a great way to showcase data from within SAP LeanIX directly, all without having to invite or create specific user accounts in SAP LeanIX.
For more information, see [Transient Users with SSO](https://help.sap.com/docs/leanix/ea/single-sign-on-sso?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cc8227a441014a371975e4b816f0a__transient-users-with-sso).
Please note, transient users need to be added in the Basic tab of Portal Configuration as well if enabled.
![Portal configuration screen showing settings for fact sheets and user access in LeanIX EAM.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27438c587a44101480bba7389e2c2bc6_LowRes.png)
